@@ -2,8 +2,10 @@
 package Bubblegum::Object::Array;
 
 use 5.10.0;
+use namespace::autoclean;
+
 use Bubblegum::Class 'with';
-use Bubblegum::Constraints -types;
+use Bubblegum::Constraints 'type_string', 'type_coderef', 'type_number';
 
 with 'Bubblegum::Object::Role::Defined';
 with 'Bubblegum::Object::Role::Indexed';
@@ -18,7 +20,7 @@ use Scalar::Util ();
 
 our @ISA = (); # non-object
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 sub all {
     my $self = CORE::shift;
@@ -375,7 +377,7 @@ Bubblegum::Object::Array - Common Methods for Operating on Array References
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
