@@ -2,15 +2,17 @@
 package Bubblegum::Object::Code;
 
 use 5.10.0;
+use namespace::autoclean;
+
 use Bubblegum::Class 'with';
-use Bubblegum::Constraints -types;
+use Bubblegum::Constraints 'type_coderef';
 
 with 'Bubblegum::Object::Role::Defined';
 with 'Bubblegum::Object::Role::Ref';
 
 our @ISA = (); # non-object
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 sub call {
     my $self = CORE::shift;
@@ -67,7 +69,7 @@ Bubblegum::Object::Code - Common Methods for Operating on Code References
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
