@@ -1,14 +1,16 @@
 package Bubblegum::Object::Role::Ref;
 
 use 5.10.0;
+use namespace::autoclean;
+
 use Bubblegum::Role 'with';
-use Bubblegum::Constraints -types;
+use Bubblegum::Constraints 'type_reference';
 
 use Scalar::Util ();
 
 with 'Bubblegum::Object::Role::Defined';
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 sub refaddr {
     my $self = type_reference CORE::shift;
