@@ -1,12 +1,14 @@
 package Bubblegum::Object::Role::Value;
 
 use 5.10.0;
+use namespace::autoclean;
+
 use Bubblegum::Role 'with';
-use Bubblegum::Constraints -types;
+use Bubblegum::Constraints 'type_coderef';
 
 with 'Bubblegum::Object::Role::Defined';
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 sub do {
     my $self = CORE::shift;
