@@ -2,17 +2,19 @@
 package Bubblegum::Object::Scalar;
 
 use 5.10.0;
+use namespace::autoclean;
+
 use Scalar::Util ();
 
 use Bubblegum::Class 'with';
-use Bubblegum::Constraints -types;
+use Bubblegum::Constraints 'type_number';
 
 with 'Bubblegum::Object::Role::Output';
 with 'Bubblegum::Object::Role::Value';
 
 our @ISA = (); # non-object
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 sub and {
     my ($self, $other) =  @_;
@@ -64,7 +66,7 @@ Bubblegum::Object::Scalar - Common Methods for Operating on Scalars
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
